@@ -1,5 +1,6 @@
 import os
 import shutil
+import sys
 from cement.utils.version import get_version_banner
 from ..core.version import get_version
 from cement import Controller, ex
@@ -40,6 +41,8 @@ class AppSetup(Controller):
         self.app.log.info(f'creating plugin {plugin_name} using language {language}')
         try:
             templates = self.app.config.get('kluff', 'templates')
+            print(templates)
+            sys.exit()
             backend_template = os.path.join(templates, language)
             frontend_template = os.path.join(templates, 'react')
             apps_path = self.app.config.get('kluff', 'apps')
